Module: GroupMixins::Developers

Extended by:
ActiveSupport::Concern
Included in:
Group
Defined in:
app/models/group_mixins/developers.rb

Overview

There are certain gloabl special groups, for example the developers group, which contains all users.

The global accessors for these groups, e.g. Group.find_developers_group or Group.developers for short, are defined in this mixin.

The mechanism used by this mixin is defined in StructureableMixins::HasSpecialGroups.

Defined Under Namespace

Modules: ClassMethods