Module: GroupMixins::HiddenUsers

Extended by:
ActiveSupport::Concern
Included in:
Group
Defined in:
app/models/group_mixins/hidden_users.rb

Overview

There are certain gloabl special groups, for example the everyone group, which contains all users.

The mechanism used by this mixin is defined in StructureableMixins::HasSpecialGroups.

Defined Under Namespace

Modules: ClassMethods