Module: GroupMixins::Corporations
- Extended by:
- ActiveSupport::Concern
- Included in:
- Group
- Defined in:
- app/models/group_mixins/corporations.rb
Overview
There are certain gloabl special groups, for example the corporations_parent group, which contains
all corporations.
The global accessors for these groups, e.g. Group.corporations_parent
are defined in this mixin.
The mechanism used by this mixin is defined in StructureableMixins::HasSpecialGroups.
Defined Under Namespace
Modules: ClassMethods